@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::Bless;
 
-our $VERSION = 0.001; # VERSION
+our $VERSION = 0.002; # VERSION
 
 our $results = [
   [
@@ -10,26 +10,26 @@ our $results = [
       {
         errors => 0,
         participant => "bless-damn-hashref-different",
-        rate => 6710650,
+        rate => 6414180,
         samples => 20,
-        time => 149.017,
+        time => 155.905,
         vs_slowest => 1,
       },
       {
-        errors => 4.1e-11,
+        errors => 0,
         participant => "bless-hashref-different",
-        rate => 9120000,
-        samples => 25,
-        time => 110,
-        vs_slowest => 1.36,
+        rate => 8572170,
+        samples => 20,
+        time => 116.657,
+        vs_slowest => 1.33644,
       },
       {
-        errors => 5.7e-11,
+        errors => 4.4e-11,
         participant => "bless-hashref-same",
-        rate => 16700000,
-        samples => 20,
-        time => 59.8,
-        vs_slowest => 2.49,
+        rate => 15300000,
+        samples => 28,
+        time => 65.3,
+        vs_slowest => 2.39,
       },
     ],
     {
@@ -152,7 +152,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2876.343,
+                                              speed                        => 2872.953,
                                               stepping                     => 4,
                                             },
                                             {
@@ -267,7 +267,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2600.171,
+                                              speed                        => 2788.187,
                                               stepping                     => 4,
                                             },
                                             {
@@ -382,7 +382,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2875.796,
+                                              speed                        => 2848.617,
                                               stepping                     => 4,
                                             },
                                             {
@@ -497,13 +497,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2865.734,
+                                              speed                        => 2805.031,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.0827209949493408,
+      "func.elapsed_time"              => 0.078449010848999,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Acme::Damn" => 0.08,
                                             "Bencher::Scenario::Bless" => undef,
                                             "Benchmark::Dumb" => "0.10",
@@ -542,9 +543,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1484221466,
       "func.scenario_module_sha1sum"   => "1cad8b10a3bccf0795a2e84c64252e51b70b814a",
       "func.scenario_module_sha256sum" => "0957711c3e18f3fc74b0645c68fa265bfe527c57b12418f1f8a640ff264df753",
-      "func.time_end"                  => 1485315247.55153,
+      "func.time_end"                  => 1485317425.18877,
       "func.time_factor"               => 1000000000,
-      "func.time_start"                => 1485315247.46881,
+      "func.time_start"                => 1485317425.11032,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ns"],
       "table.fields"                   => [
